/*========================================================================
 * Written by D. Jason Penney, 1991.  Rights to this program are as follows:
 * you may not receive any compensation for distribution of this program
 * except for an optional fee for the distribution medium.  This program
 * must be accompanied by this source code.  This notice may not be removed.
 * Modifications to this program must be clearly noted and marked as such.
 * Since this program is provided free of charge, there is ABSOLUTELY NO
 * WARRANTY.
 *
 * Name - getpwnam.c
 *
 * Description - 
 *
 * Compile with:
 *   cc -o getpwnam getpwnam.c
 *   chmod 555 getpwnam
 *
 * $Id: getpwnam.c,v 1.5 2007-11-24 04:07:30 normg Exp $
 *
 * $Log: not supported by cvs2svn $
 * Revision 1.2.8.1  2007/07/09 22:36:05  normg
 * Add support for Darwin (Apple UNIX on x86)
 * Port AIO code from GS64
 * Port serverprim.c code from GS64
 * Convert free() to UtlFree() so heap checking works
 * Port faster unixFileIsLocal() code in rdbfio.c from GS64
 *
 * Revision 1.2  2002/06/04 00:00:22  normg
 * Add support for Linux 2.4 kernel.
 * -add support for multiple CPUs
 * -add assembler spin lock routines
 * -add support for native code (not fully functional yet)
 * -use poll instead of select
 *
 * Modified Files:
 * build/release/PACKING.be build/release/makeprod.pl
 * build/release/misc.pl build/ship/partnummapping.pl
 * gsmake/gsmake.mak scripts/install/gethostbyname.c
 * scripts/install/getpwnam.c scripts/install/makeinstall.sh
 * scripts/install/shmem.c scripts/sh/filedesc.csh
 * scripts/sh/fixman.sh src/bemake src/bemake.mak src/flag.ht
 * src/gemcopy.hc src/gemmain.c src/global.ht src/host.ht
 * src/hostasm.c src/hostshr.c src/hostshr.hf src/hostshr.ht
 * src/hostunix.c src/interp.ht src/intloop.c src/krbdb.c
 * src/krbsrv.c src/natgen.ht src/nattxt.hf src/nattxt_x86nt.s
 * src/partime.hf src/session.ht src/shrpccmn.c src/stonecfg.ht
 * src/stoned.c src/unixerr.c
 *
 * Added Files:
 * scripts/sh/misc.linux.sh src/hostlinux-x86.s
 * src/natemit_x86linux.c src/nattxt_x86linux.S
 *
 * Revision 1.1.1.1  2002/03/08 17:45:35  otisa
 * New Gs/S 6.0 repository as of 6.0 FCS
 *
 * Revision 50.2  1999/02/03 03:04:59  daleh
 * finished first round of linux port
 *
 * Revision 50.1.1.1  1995/08/08 23:54:16  darrel
 * 5.0 backend sources
 *
 * Revision 41.3  1995/03/04 20:30:06  darrel
 * Now compile and link on HPUX.
 *
 * Revision 41.2  1994/11/14  21:17:00  jason
 * Roll forward the NCR changes
 *
 * Revision 41.1  1994/11/02  22:40:38  jason
 * Added asyncio and getpwnam
 *
 * Revision 1.1.1.2  1992/11/03  18:44:58  penneyj
 * many fixes
 *
 * Revision 1.1.1.1  1991/05/01  19:40:38  penneyj
 * *** empty log message ***
 *
 * Revision 1.1  1991/05/01  19:40:37  penneyj
 * Initial revision
 *
 *========================================================================
 */

#if defined(__hpux)
#if !defined(_HPUX_SOURCE)
#define _HPUX_SOURCE
#endif /* !defined(_HPUX_SOURCE) */
#include <sys/stdsyms.h> /* Pick up the other related #defs */
#endif

#include <stdlib.h>
#include <stdio.h>
#include <pwd.h>
#include <ctype.h>
#include <errno.h>
#include <unistd.h>

int main(argc, argv)
int argc;
char *argv[];
{
struct passwd *this;

if (argc != 2) {
  printf("Usage: %s <user-name>\n", argv[0]);
  exit(1);
  }

this = getpwnam(argv[1]);
if (this == NULL) {
  printf("%s:  (no entry, errno = %d)\n", argv[1], errno);
  exit(1);
  }

printf("pw_name='%s', pw_passwd='%s', pw_uid=%d, pw_gid=%d\n",
    this->pw_name, this->pw_passwd, this->pw_uid, this->pw_gid);

#if defined(RISC6000AIX) || defined(i386linux) || defined(i686Linux) || defined(__APPLE_CC__)
#else
printf("pw_age='%s', pw_comment='%s'\n", this->pw_age, this->pw_comment);
#endif

printf("pw_gecos='%s', pw_dir='%s', pw_shell='%s'\n",
    this->pw_gecos, this->pw_dir, this->pw_shell);
return 0;
}
